@@ -42,7 +42,7 @@ from .site import (
     RequestRevisions, MultiRequestRevisions,
 )
 from .file import TrackedFile, Revision, DefaultFileMap
-from .kitsu import KitsuAPIWrapper, KitsuBindings, KitsuUsers
+from .kitsu import KitsuAPIWrapper, KitsuBindings, KitsuUsers, KitsuTasks
 from .dependency import DependencyTemplates
 
 
@@ -357,6 +357,7 @@ class KitsuConfig(flow.Object):
         action_submenus=True,
         items_action_submenus=True,
     )
+    tasks = flow.Child(KitsuTasks)
     gazu_api = flow.Child(KitsuAPIWrapper).ui(
         hidden=True
     )
