@@ -94,6 +94,17 @@ class KitsuAPIWrapper(flow.Object):
 
         return True
     
+    def get_task_name(self, project_task_name, project_subtask_name):
+        kitsu_task = None
+
+        if self._config.tasks.has_mapped_name(project_task_name):
+            subtasks = self._config.tasks[project_task_name].subtasks
+            
+            if subtasks.has_mapped_name(project_subtask_name):
+                kitsu_task = subtasks[project_subtask_name].get()
+        
+        return kitsu_task
+    
     def get_project_id(self):
         import requests
         try:
@@ -152,16 +163,13 @@ class KitsuAPIWrapper(flow.Object):
                             break
                     
                     if has_valid_status:
-                        shots.append(gazu.shot.get_shot(shot_id))
+                        shot = gazu.shot.get_shot(shot_id)
+                        shots.append((shot['sequence_name'], shot['name']))
         else:
-            shots = gazu.shot.all_shots_for_project(
-                self.get_project_id()
-            )
-        
-        shots = [
-            (gazu.shot.get_sequence_from_shot(s)['name'], s['name'])
-            for s in shots
-        ]
+            shots = [
+                (gazu.shot.get_sequence_from_shot(s)['name'], s['name'])
+                for s in gazu.shot.all_shots_for_project(self.get_project_id())
+            ]
         
         return shots
     
@@ -502,37 +510,6 @@ class ChangeKitsuUserLogin(flow.Action):
         self._map.touch()
 
 
-# class KitsuShot(Entity):
-
-#     kitsu_shot_names = Property()
-
-
-# class KitsuShots(EntityCollection):
-
-#     @classmethod
-#     def mapped_type(cls):
-#         return KitsuShot
-    
-#     def add_shot(self, shot_oid):
-#         self.get_entity_store().get_collection(self.collection_name()).insert_one(
-#             {'name': self._oid_to_mapped_name(shot_oid)},
-#             {'kitsu_shot_names': []}
-#         )
-    
-#     def _oid_to_mapped_name(self, oid):
-#         return oid.replace('/', '_')[1:]
-
-
-class AbstractKitsuShot:
-
-    def set_task_status(self, task_name, task_status):
-        raise NotImplementedError((
-            'Must set the status of the given task '
-            'of the Kitsu shot entity corresponding '
-            'to this shot object.'
-        ))
-
-
 class KitsuUser(flow.SessionObject):
     
     edit = flow.Child(ChangeKitsuUserLogin)
@@ -564,6 +541,76 @@ class KitsuUsers(flow.DynamicMap):
         style['activate_oid'] = item.edit.oid()
 
 
+class EditKitsuSubtask(flow.Action):
+
+    kitsu_task = flow.SessionParam('')
+
+    _subtask = flow.Parent()
+    _map  = flow.Parent(2)
+
+    def needs_dialog(self):
+        self.kitsu_task.set(self._subtask.get())
+        return True
+    
+    def get_buttons(self):
+        return ['Save', 'Cancel']
+    
+    def run(self, button):
+        if button == 'Cancel':
+            return
+        
+        self._subtask.set(self.kitsu_task.get())
+        self._map.touch()
+
+
+class KitsuSubtask(flow.values.Value):
+    
+    edit = flow.Child(EditKitsuSubtask)
+
+
+class KitsuSubtasks(flow.DynamicMap):
+
+    _task = flow.Parent()
+
+    @classmethod
+    def mapped_type(cls):
+        return KitsuSubtask
+
+    def mapped_names(self, page_num=0, page_size=None):
+        tm = self.root().project().get_task_manager()
+        return tm.get_subtasks(self._task.name())
+    
+    def columns(self):
+        return ['Name', 'Kitsu task']
+    
+    def _fill_row_cells(self, row, item):
+        row['Name'] = item.name()
+        row['Kitsu task'] = item.get()
+    
+    def _fill_row_style(self, style, item, row):
+        style['activate_oid'] = item.edit.oid()
+
+
+class KitsuTask(flow.Object):
+    
+    subtasks = flow.Child(KitsuSubtasks).ui(
+        expanded=True,
+        action_submenus=True,
+        items_action_submenus=True,
+    )
+
+
+class KitsuTasks(flow.DynamicMap):
+
+    @classmethod
+    def mapped_type(cls):
+        return KitsuTask
+
+    def mapped_names(self, page_num=0, page_size=None):
+        tm = self.root().project().get_task_manager()
+        return tm.default_tasks.mapped_names()
+
+
 class KitsuTaskStatus(PresetChoiceValue):
     
     DEFAULT_EDITOR = 'choice'
