@@ -14,7 +14,7 @@ class AssetDepartments(flow.Object):
 
 class Asset(baseflow.lib.Asset):
 
-    departments = flow.Child(AssetDepartments).ui(expanded=True)
+    tasks = flow.Child(AssetDepartments).ui(expanded=True)
 
     def compute_child_value(self, child_value):
         if child_value is self.kitsu_url:
